import os

def generate_gradient(color1, color2, steps=16):
    gradient = []
    for i in range(steps):
        ratio = i / (steps - 1)
        r = int(color1[0] + (color2[0] - color1[0]) * ratio)
        g = int(color1[1] + (color2[1] - color1[1]) * ratio)
        b = int(color1[2] + (color2[2] - color1[2]) * ratio)
        gradient.extend([r, g, b])
        if i < steps - 1:
            gradient.append(0)  # Add 00 byte after each color except the last one
    gradient.append(0)  # Add 00 byte at the end
    return gradient

def replace_gradient_in_pal(file_path, gradient):
    with open(file_path, 'r+b') as file:
        file.seek(0x318)
        for color_value in gradient:
            file.write(bytes([color_value]))

def process_pal_files(input_folder, output_folder, color1, color2):
    gradient = generate_gradient(color1, color2)
    for root, _, files in os.walk(input_folder):
        for file in files:
            if file.endswith('.pal'):
                input_path = os.path.join(root, file)
                output_path = input_path.replace(input_folder, output_folder)
                os.makedirs(os.path.dirname(output_path), exist_ok=True)
                replace_gradient_in_pal(input_path, gradient)
                with open(input_path, 'rb') as source_file, open(output_path, 'wb') as dest_file:
                    dest_file.write(source_file.read())

# Example usage:
input_folder = 'input'
output_folder = 'output'
color1 = (0x00, 0x00, 0x00)  # Top color
color2 = (0x80, 0x40, 0x00)  # Bottom color
process_pal_files(input_folder, output_folder, color1, color2)